Pygerrit2 - Client library for interacting with Gerrit Code Review's REST API
=============================================================================

.. image:: https://img.shields.io/pypi/v/pygerrit2.svg

.. image:: https://img.shields.io/pypi/l/pygerrit2.svg

.. image:: https://travis-ci.org/dpursehouse/pygerrit2.svg?branch=master

.. image:: https://api.dependabot.com/badges/status?host=github&repo=dpursehouse/pygerrit2

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg

Pygerrit2 provides a simple interface for clients to interact with
`Gerrit Code Review`_ via the REST API.

Copyright and License
---------------------

Copyright 2011 Sony Ericsson Mobile Communications. All rights reserved.

Copyright 2012 Sony Mobile Communications. All rights reserved.

Copyright 2016 David Pursehouse. All rights reserved.

Licensed under The MIT License.  Please refer to the `LICENSE`_ file for full
license details.

.. _`Gerrit Code Review`: https://gerritcodereview.com/
.. _LICENSE: https://github.com/dpursehouse/pygerrit2/blob/master/LICENSE
